@@ -5,7 +5,7 @@ from typing import Dict, List
 
 import regex as re
 
-from .helpers import inside_ignored_block, inside_ignored_rule
+from .helpers import inside_ignored_rule, overlaps_ignored_block
 from .settings import Config
 
 flags = {
@@ -99,7 +99,7 @@ def lint_file(config: Config, this_file: Path) -> Dict:
 
                 for match in open_tags:
                     if (
-                        inside_ignored_block(config, html, match) is False
+                        overlaps_ignored_block(config, html, match) is False
                         and inside_ignored_rule(config, html, match, rule["name"])
                         is False
                     ):
@@ -119,7 +119,7 @@ def lint_file(config: Config, this_file: Path) -> Dict:
                     html,
                 ):
                     if (
-                        inside_ignored_block(config, html, match) is False
+                        overlaps_ignored_block(config, html, match) is False
                         and inside_ignored_rule(config, html, match, rule["name"])
                         is False
                     ):
